==> haskell-http-date-0.0.8-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-date.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-date
version: 0.0.8
id: http-date-0.0.8-2EyIwRPz1L26ax5eUhXbWy
key: http-date-0.0.8-2EyIwRPz1L26ax5eUhXbWy
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: HTTP Date parser/formatter
description:
    Fast parser and formatter for HTTP Date
category: Network, Web
abi: 3f1793c5ccfe17305b78430bf78317a4
exposed: True
exposed-modules:
    Network.HTTP.Date
hidden-modules: Network.HTTP.Date.Converter
                Network.HTTP.Date.Formatter Network.HTTP.Date.Types
                Network.HTTP.Date.Parser
import-dirs: /usr/lib/ghc-8.6.1/site-local/http-date-0.0.8
library-dirs: /usr/lib/ghc-8.6.1/site-local/http-date-0.0.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/http-date-0.0.8
hs-libraries: HShttp-date-0.0.8-2EyIwRPz1L26ax5eUhXbWy
depends:
    array-0.5.2.0 attoparsec-0.13.2.2-FwHjzt71DhSHhjVAq259Rs
    base-4.12.0.0 bytestring-0.10.8.2 time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-http-date/html/http-date.haddock
haddock-html: /usr/share/doc/haskell-http-date/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-date-0.0.8-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-date.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-date
version: 0.0.8
id: http-date-0.0.8-61YMvfEKCGC3eCoo5XW90
key: http-date-0.0.8-61YMvfEKCGC3eCoo5XW90
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: HTTP Date parser/formatter
description:
    Fast parser and formatter for HTTP Date
category: Network, Web
abi: f3f9c1b950acd889f5e0d83568323ea1
exposed: True
exposed-modules:
    Network.HTTP.Date
hidden-modules: Network.HTTP.Date.Converter
                Network.HTTP.Date.Formatter Network.HTTP.Date.Types
                Network.HTTP.Date.Parser
import-dirs: /usr/lib/ghc-8.6.1/site-local/http-date-0.0.8
library-dirs: /usr/lib/ghc-8.6.1/site-local/http-date-0.0.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/http-date-0.0.8
hs-libraries: HShttp-date-0.0.8-61YMvfEKCGC3eCoo5XW90
depends:
    array-0.5.2.0 attoparsec-0.13.2.2-HPD0YgNwhBr5J2x8QxeYlI
    base-4.12.0.0 bytestring-0.10.8.2 time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-http-date/html/http-date.haddock
haddock-html: /usr/share/doc/haskell-http-date/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
